Library class

Constructors

Library()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

flagFirst ↔ bool
getter/setter pair
libmpv ↔ LibMPV
getter/setter pair
loaded ↔ bool
getter/setter pair

Static Methods

init({String? path}) → void