Player class

Constructors

Player(Map<String, String> options, {bool initialize = true, bool videoOutput = false})

Properties

audioParams → ValueNotifier<AudioParams>
final
ctx ↔ Pointer<mpv_handle>
getter/setter pair
duration → ValueNotifier<int>
final
handle → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → ValueNotifier<int>
final
paused → ValueNotifier<bool>
final
position → ValueNotifier<int>
final
propertyChangedCallback ↔ dynamic Function(String, mpv_format)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → ValueNotifier<double>
final
videoParams → ValueNotifier<VideoParams>
final
volume → ValueNotifier<double>
final

Methods

command(List<String> args) → void
commandNode(Pointer<mpv_node> node1, Pointer<mpv_node> node2) → void
destroy() → void
init({bool videoOutput = false}) → void
initVO() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observeProperty(String property, mpv_format format, {int propertyId = 0}) → void
setOption(String name, dynamic value) → void
setOptionAll(String name, mpv_format format, Pointer<Void> data) → void
setOptionDouble(String name, double value) → void
setOptionFlag(String name, bool value) → void
setOptionInt64(String name, int value) → void
setOptionNode(String name, Pointer<mpv_node> node) → void
setOptionString(String name, String value) → void
setOutputSize({int? width, int? height}) → Future<void>
setProperty(String name, dynamic value) → void
setPropertyDouble(String name, double value) → void
setPropertyFlag(String name, bool value) → void
setPropertyInt64(String name, int value) → void
setPropertyNode(String name, Pointer<mpv_node> node) → void
setPropertyString(String name, String value) → void
toString() → String
A string representation of this object.
inherited
unObserveProperty(int propertyId, {String? propertyName}) → void
waitEvent(double timeout) → Pointer<mpv_event>

Operators

operator ==(Object other) → bool
The equality operator.
inherited