AudioParams class

Constructors

AudioParams({String? format, int? sampleRate, String? channels, int? channelCount, String? hrChannels})
const

Properties

channelCount → int?
Number of audio channels.
final
channels → String?
The channel layout as a string. This is similar to what the --audio-channels accepts.
final
format → String?
The sample format as string. This uses the same names as used in other places of mpv.
final
hashCode → int
The hash code for this object.
no setteroverride
hrChannels → String?
As channels, but instead of the possibly cryptic actual layout sent to the audio device, return a hopefully more human readable form. Usually only audio-out-params/hr-channels makes sense.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int?
Sample rate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override